require_relative '../../../../test_helper'

module Landrush
  module Cap
    module Darwin
      describe ConfigureVisibilityOnHost do
        let(:env) { Vagrant::Environment.new }

        CONFIG = <<-EOF.gsub(/^ +/, '')
        # Generated by landrush, a vagrant plugin
        nameserver 127.0.0.1
        port #{Server.port}
        EOF

        describe 'configure_visibility_on_host' do
          it 'writes a resolver config on the host' do
            Dir.mktmpdir('landrush-test-dir-') do |dir|
              # puts "Using #{dir} for testing"
              Dir["#{dir}/*"].empty?.must_equal true

              # stub some internal methods to make sure config gets written into tmp directory
              ConfigureVisibilityOnHost.stubs(:config_dir).returns(Pathname(dir))
              # also disable 'sudo'
              ConfigureVisibilityOnHost.stubs(:sudo).returns('')

              ConfigureVisibilityOnHost.configure_visibility_on_host(env, '42.42.42.42', ['vagrant.test'])

              Dir["#{dir}/*"].empty?.must_equal false
              File.exist?(File.join(dir, 'vagrant.test')).must_equal true
              Pathname(File.join(dir, 'vagrant.test')).read.must_equal CONFIG
            end
          end

          it 'multiple tlds can be specified' do
            Dir.mktmpdir('landrush-test-dir-') do |dir|
              # puts "Using #{dir} for testing"
              Dir["#{dir}/*"].empty?.must_equal true

              # stub some internal methods to make sure config gets written into tmp directory
              ConfigureVisibilityOnHost.stubs(:config_dir).returns(Pathname(dir))
              # also disable 'sudo'
              ConfigureVisibilityOnHost.stubs(:sudo).returns('')

              tlds = %w[foo.bar acme.com example.com]

              ConfigureVisibilityOnHost.configure_visibility_on_host(env, '42.42.42.42', tlds)

              tlds.each do |tld|
                Dir["#{dir}/*"].empty?.must_equal false
                File.exist?(File.join(dir, tld)).must_equal true
                Pathname(File.join(dir, tld)).read.must_equal CONFIG
              end
            end
          end
        end
      end
    end
  end
end
